nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Epskip

Struct Epskip 

#[repr(transparent)]
pub struct Epskip(pub u32);
USB Endpoint skip

Tuple Fields

0: u32

Implementations

Source

impl Epskip

pub const fn skip(&self) -> u16

Endpoint skip: Writing 1 to one of these bits, will indicate to HW that it must deactivate the buffer assigned to this endpoint and return control back to software. When HW has deactivated the endpoint, it will clear this bit, but it will not modify the EPINUSE bit. An interrupt will be generated when the Active bit goes from 1 to 0. Note: In case of double-buffering, HW will only clear the Active bit of the buffer indicated by the EPINUSE bit.

pub const fn set_skip(&mut self, val: u16)

Endpoint skip: Writing 1 to one of these bits, will indicate to HW that it must deactivate the buffer assigned to this endpoint and return control back to software. When HW has deactivated the endpoint, it will clear this bit, but it will not modify the EPINUSE bit. An interrupt will be generated when the Active bit goes from 1 to 0. Note: In case of double-buffering, HW will only clear the Active bit of the buffer indicated by the EPINUSE bit.