#[repr(transparent)]pub struct Eptoggle(pub u32);Expand description
USB Endpoint toggle register
Tuple Fields
0: u32Implementations
Sourceimpl Eptoggle
impl Eptoggle
Sourcepub const fn toggle(&self) -> u16
pub const fn toggle(&self) -> u16
Endpoint data toggle: This field indicates the current value of the data toggle for the corresponding endpoint.
Sourcepub const fn set_toggle(&mut self, val: u16)
pub const fn set_toggle(&mut self, val: u16)
Endpoint data toggle: This field indicates the current value of the data toggle for the corresponding endpoint.