#[repr(transparent)]pub struct Info(pub u32);Expand description
USB Info register
Tuple Fields
0: u32Implementations
Sourceimpl Info
impl Info
Sourcepub const fn frame_nr(&self) -> u16
pub const fn frame_nr(&self) -> u16
Frame number. This contains the frame number of the last successfully received SOF. In case no SOF was received by the device at the beginning of a frame, the frame number returned is that of the last successfully received SOF. In case the SOF frame number contained a CRC error, the frame number returned will be the corrupted frame number as received by the device.
Sourcepub const fn set_frame_nr(&mut self, val: u16)
pub const fn set_frame_nr(&mut self, val: u16)
Frame number. This contains the frame number of the last successfully received SOF. In case no SOF was received by the device at the beginning of a frame, the frame number returned is that of the last successfully received SOF. In case the SOF frame number contained a CRC error, the frame number returned will be the corrupted frame number as received by the device.
Sourcepub const fn set_err_code(&mut self, val: ErrCode)
pub const fn set_err_code(&mut self, val: ErrCode)
The error code which last occurred:
Sourcepub const fn set_minrev(&mut self, val: u8)
pub const fn set_minrev(&mut self, val: u8)
Minor Revision.
Sourcepub const fn set_majrev(&mut self, val: u8)
pub const fn set_majrev(&mut self, val: u8)
Major Revision.