#[repr(transparent)]pub struct Lpm(pub u32);Expand description
USB Link Power Management register
Tuple Fields
0: u32Implementations
Sourceimpl Lpm
impl Lpm
Sourcepub const fn hird_hw(&self) -> u8
pub const fn hird_hw(&self) -> u8
Host Initiated Resume Duration - HW. This is the HIRD value from the last received LPM token
Sourcepub const fn set_hird_hw(&mut self, val: u8)
pub const fn set_hird_hw(&mut self, val: u8)
Host Initiated Resume Duration - HW. This is the HIRD value from the last received LPM token
Sourcepub const fn hird_sw(&self) -> u8
pub const fn hird_sw(&self) -> u8
Host Initiated Resume Duration - SW. This is the time duration required by the USB device system to come out of LPM initiated suspend after receiving the host initiated LPM resume.
Sourcepub const fn set_hird_sw(&mut self, val: u8)
pub const fn set_hird_sw(&mut self, val: u8)
Host Initiated Resume Duration - SW. This is the time duration required by the USB device system to come out of LPM initiated suspend after receiving the host initiated LPM resume.
Sourcepub const fn data_pending(&self) -> bool
pub const fn data_pending(&self) -> bool
As long as this bit is set to one and LPM supported bit is set to one, HW will return a NYET handshake on every LPM token it receives. If LPM supported bit is set to one and this bit is zero, HW will return an ACK handshake on every LPM token it receives. If SW has still data pending and LPM is supported, it must set this bit to 1.
Sourcepub const fn set_data_pending(&mut self, val: bool)
pub const fn set_data_pending(&mut self, val: bool)
As long as this bit is set to one and LPM supported bit is set to one, HW will return a NYET handshake on every LPM token it receives. If LPM supported bit is set to one and this bit is zero, HW will return an ACK handshake on every LPM token it receives. If SW has still data pending and LPM is supported, it must set this bit to 1.