#[repr(transparent)]pub struct Epbufcfg(pub u32);Expand description
USB Endpoint Buffer Configuration register
Tuple Fields
0: u32Implementations
Sourceimpl Epbufcfg
impl Epbufcfg
Sourcepub const fn buf_sb(&self) -> u8
pub const fn buf_sb(&self) -> u8
Buffer usage: This register has one bit per physical endpoint. 0: Single-buffer. 1: Double-buffer. If the bit is set to single-buffer (0), it will not toggle the corresponding EPINUSE bit when it clears the active bit. If the bit is set to double-buffer (1), HW will toggle the EPINUSE bit when it clears the Active bit for the buffer.
Sourcepub const fn set_buf_sb(&mut self, val: u8)
pub const fn set_buf_sb(&mut self, val: u8)
Buffer usage: This register has one bit per physical endpoint. 0: Single-buffer. 1: Double-buffer. If the bit is set to single-buffer (0), it will not toggle the corresponding EPINUSE bit when it clears the active bit. If the bit is set to double-buffer (1), HW will toggle the EPINUSE bit when it clears the Active bit for the buffer.